@@ -38,12 +38,13 @@ class SQSQueuePolicyNotPrincipalRule(ResourceSpecificRule):
 
     def resource_invoke(self, resource: SQSQueuePolicy, logical_id: str, extras: Optional[Dict] = None) -> Result:
         result = Result()
-        for statement in resource.Properties.PolicyDocument._statement_as_list():
+        for statement in resource.Properties.PolicyDocument.statement_as_list():
             if statement.NotPrincipal:
                 self.add_failure_to_result(
                     result,
                     self.REASON.format(logical_id),
                     resource_ids={logical_id},
+                    resource_types={resource.Type},
                     context={
                         "config": self._config,
                         "extras": extras,
@@ -80,7 +81,7 @@ class SQSQueuePolicyPublicRule(ResourceSpecificRule):
     def resource_invoke(self, resource: SQSQueuePolicy, logical_id: str, extras: Optional[Dict] = None) -> Result:
         result = Result()
         if resource.Properties.PolicyDocument.allowed_principals_with(REGEX_HAS_STAR_OR_STAR_AFTER_COLON):
-            for statement in resource.Properties.PolicyDocument._statement_as_list():
+            for statement in resource.Properties.PolicyDocument.statement_as_list():
                 if statement.Effect == "Allow" and statement.principals_with(REGEX_HAS_STAR_OR_STAR_AFTER_COLON):
                     if statement.Condition and statement.Condition.dict():
                         # Ignoring condition checks since they will get reviewed in other rules and future improvements
@@ -90,6 +91,7 @@ class SQSQueuePolicyPublicRule(ResourceSpecificRule):
                             result,
                             self.REASON.format(logical_id),
                             resource_ids={logical_id},
+                            resource_types={resource.Type},
                             context={
                                 "config": self._config,
                                 "extras": extras,
